==> ocp-common-3.0.0-20200715.040111-78-sources.jar: com/efuture/ocp/common/entity/FileImportObject.java <==
/**
 * Copyright (C), 2007-2014, eFuture 北京富基融通科技有限公司
 * FileName:	FileObject.java
 * Author:		亮
 * Date:		2014-4-9 下午5:28:08
 * Description:	
 * History:
 * <author>		<time>			<version>		<description>
 * 
 */
package com.efuture.ocp.common.entity;

import java.io.InputStream;

import javax.servlet.http.HttpServletRequest;

/**
 * @author		亮
 * @description	
 * 
 */
public class FileImportObject
{
    protected String filename;
    protected long filelength;
    protected InputStream stream;
    
    protected HttpServletRequest servletrequest;
    
    /**
     * @return filename
     */
    public String getFilename()
    {
        return filename;
    }
    /**
     * @param filename 要设置的 filename
     */
    public void setFilename(String filename)
    {
        this.filename = filename;
    }
    /**
     * @return stream
     */
    public InputStream getStream()
    {
        return stream;
    }
    /**
     * @param stream 要设置的 stream
     */
    public void setStream(InputStream stream)
    {
        this.stream = stream;
    }
    
    /**
     * @return filelength
     */
    public long getFilelength()
    {
        return filelength;
    }
    /**
     * @param filelength 要设置的 filelength
     */
    public void setFilelength(long filelength)
    {
        this.filelength = filelength;
    }
    /**
     * @return servletrequest
     */
    public HttpServletRequest getServletrequest()
    {
        return servletrequest;
    }
    /**
     * @param servletrequest 要设置的 servletrequest
     */
    public void setServletrequest(HttpServletRequest servletrequest)
    {
        this.servletrequest = servletrequest;
    }
    
    
}

==> ocp-common-5.0.0-20231208.095419-102-sources.jar: com/efuture/ocp/common/entity/FileImportObject.java <==
/**
 * Copyright (C), 2007-2014, eFuture 北京富基融通科技有限公司
 * FileName:	FileObject.java
 * Author:		亮
 * Date:		2014-4-9 下午5:28:08
 * Description:
 * History:
 * <author>		<time>			<version>		<description>
 *
 */
package com.efuture.ocp.common.entity;

import java.io.InputStream;

import javax.servlet.http.HttpServletRequest;

/**
 * @author		亮
 * @description
 *
 */
public class FileImportObject
{
    protected String filename;
    protected long filelength;
    protected String filetype;
    protected InputStream stream;

    protected HttpServletRequest servletrequest;

    /**
     * @return filename
     */
    public String getFilename()
    {
        return filename;
    }
    /**
     * @param filename 要设置的 filename
     */
    public void setFilename(String filename)
    {
        this.filename = filename;
    }
    /**
     * @return stream
     */
    public InputStream getStream()
    {
        return stream;
    }
    /**
     * @param stream 要设置的 stream
     */
    public void setStream(InputStream stream)
    {
        this.stream = stream;
    }

    /**
     * @return filelength
     */
    public long getFilelength()
    {
        return filelength;
    }
    /**
     * @param filelength 要设置的 filelength
     */
    public void setFilelength(long filelength)
    {
        this.filelength = filelength;
    }
    /**
     * @return servletrequest
     */
    public HttpServletRequest getServletrequest()
    {
        return servletrequest;
    }
    /**
     * @param servletrequest 要设置的 servletrequest
     */
    public void setServletrequest(HttpServletRequest servletrequest)
    {
        this.servletrequest = servletrequest;
    }

    public String getFiletype()
    {
        return filetype;
    }

    public void setFiletype(String filetype)
    {
        this.filetype = filetype;
    }
}
